Module mailchimp_api::types
source · Expand description
The data types sent to and returned from the API client.
Structs
Stats for Campaign A.
A breakdown of clicks by different groups of an A/B Split campaign. Does not return information about Multivariate Campaigns.
The settings specific to A/B test campaigns.
General stats about different groups of an A/B Split campaign. Does not return information about Multivariate Campaigns.
A/B Testing options for a campaign.
abandonedBrowse automation details. abandonedBrowse is also known as Product Retargeting Email or Retarget Site Visitors on the web.
abandonedCart automation details.
Details of abuse complaints for a specific list. An abuse complaint occurs when your recipient clicks to ‘report spam’ in their email program.
A collection of abuse complaints for a specific list. An abuse complaint occurs when your recipient clicks to ‘report spam’ in their email program.
A list of abuse complaints for a specific list.
Details of abuse complaints for a specific list. An abuse complaint occurs when your recipient clicks to ‘report spam’ in their email program.
One day’s worth of list activity. Doesn’t include Automation activity.
Individuals who are currently or have been previously subscribed to this list, including members who have bounced or unsubscribed.
Individuals who are currently or have been previously subscribed to this list, including members who have bounced or unsubscribed.
Individuals who are currently or have been previously subscribed to this list, including members who have bounced or unsubscribed.
Configure a webhook for the given list.
The customer’s address.
Segment by an address-type merge field.
Segment by an address-type merge field within a given distance.
Campaign feedback details.
An option for Signup Form Styles.
API health status.
The API root resource links to all other resources available in the API.
An authorized app.
Available when uploading an archive to create campaign content. The archive should include all campaign content and images. Learn more.
Audience settings
The settings for the Automation workflow.
The delay settings for an automation email.
A summary of the emails in an Automation workflow.
List settings for the campaign.
Segment by interaction with an Automation workflow.
Trigger settings for the Automation.
A summary of an individual Automation workflow’s settings and content.
A summary of an individual Automation workflow’s settings and content.
Stats for Campaign B.
The status of a batch request
Batch add/remove List members to/from static segment
Choose whether the campaign should use Batch Delivery. Cannot be set to
true for campaigns using Timewarp.A summary of batch requests that have been made.
Batch update list members.
Subscriber location information.
Add a new Batch Webook.
Manage webhooks for batch requests.
The billing address for the order.
Segment by a contact’s birthday.
An object describing the bounce summary for the campaign.
A summary of an individual campaign’s settings and content.
The settings specific to A/B test campaigns.
A list of feedback based on a campaign’s statistics.
The HTML and plain-text content for a campaign.
The HTML and plain-text content for a campaign
A summary of an individual campaign’s settings and content.
A summary of an individual campaign’s settings and content.
Default values for campaigns created for this list.
A specific feedback message from a specific campaign.
A specific feedback message from a specific campaign.
A specific feedback message from a specific campaign.
A folder used to organize campaigns.
A list of campaign folders
List settings for the campaign.
List settings for the campaign.
For sent campaigns, a summary of opens and clicks.
For sent campaigns, a summary of opens and clicks.
A summary of the comment feedback for a specific campaign.
A list of reports containing campaigns marked as Sent.
The average campaign statistics for your industry.
RSS options for a campaign.
RSS options for a campaign.
Settings for the campaign including the email subject, from name, and from email address.
The settings for your campaign, including subject, from name, reply-to address, and more.
A list of reports containing child campaigns for a specific campaign.
The tracking options for a campaign.
Campaigns and Snippets found for given search term.
Deprecated
A collection of a cart’s line items.
Information about a specific cart.
A collection of a store’s carts.
Interest categories organize interests, which are used to group subscribers based on their preferences. These correspond to Group Titles the application.
Channel settings
A Chimp Chatter message
A subscriber who clicked a specific URL in a specific campaign.
A collection of members who clicked on a specific link within a campaign.
A list of URLs and unique IDs included in HTML and plain-text versions of a campaign.
A summary of the click-throughs on the campaign’s URL.
An object describing the click activity for the campaign.
The email client.
Messages from a specific conversation.
A collection of events for a given contact
The last 50 Goal events for a member on a specific list.
The merge fields (audience fields) for an audience.
The last 10 notes for a specific list member, based on date created.
A specific note for a specific member.
A list of available segments.
A list of tags assigned to a list member.
Segment by interaction with a specific campaign.
Information about a specific connected site.
A collection of connected sites in the account.
Do particular authorization constraints around this collection limit creation of new instances?
Information about the account contact.
Activity feed item that represents a generic event.
Collection of Content for List Signup Forms.
Details about an individual conversation. Conversation tracking is a feature available to paid accounts that lets you view replies to your campaigns in your Mailchimp account.
An individual message in a conversation. Conversation tracking is a feature available to paid accounts that lets you view replies to your campaigns in your Mailchimp account.
Segment by interaction with a campaign via Conversations.
A summary of an individual campaign’s settings and content.
List settings for the campaign.
An object representing all segmentation options. This object should contain a
saved_segment_id to use an existing segment, or you can create a new segment by including both match and conditions options.The settings for your campaign, including subject, from name, reply-to address, and more.
Information about a specific customer.
A collection of the store’s customers.
The days of the week to send a daily RSS Campaign.
The clicks and visits data from the last seven days.
Segment by a given date merge field.
Segment by a specific date field.
The delay settings for an Automation email.
Updates on campaigns in the process of sending.
Statistics for the top-performing email domains in a campaign.
A single email domain’s performance
An individual segment condition
Information about a specific cart.
Information about a specific customer. Orders for existing customers should include only the
id parameter in the customer object body.Information about a specific cart.
Information about a specific cart line item.
Information about a specific cart line item.
Information about a specific cart line item.
Information about a specific customer. For existing customers include only the
id parameter in the customer object body.Information about a specific customer.
Information about a specific customer. Orders for existing customers should include only the
id parameter in the customer object body.Information about a specific order.
Information about a specific order.
Information about a specific order line.
Information about a specific order line.
The outreach associated with this order. For example, an email campaign or Facebook ad.
Information about a specific product.
Information about a specific product.
Information about a specific product.
Information about a specific product image.
Information about a specific product image.
Information about a specific product variant.
Information about a specific product variant.
Information about an Ecommerce Store’s specific Promo Code.
Information about an Ecommerce Store’s specific Promo Code.
Information about an Ecommerce Store’s specific Promo Rule.
Information about an Ecommerce Store’s specific Promo Rule.
E-Commerce stats for a campaign.
An individual store in an account.
An individual store in an account.
A collection of stores in the account.
The store address.
Details for the automations attached to this store.
The Connected Site associated with the store.
E-Commerce stats for a campaign.
Segment by purchases in specific items or categories.
Ecommerce stats for the list member if the list is attached to a store.
Segment by average spent total, number of orders, total number of products purchased, or average number of products per order.
Activity feed item that represents an order.
A collection of a product’s images.
A collection of a product’s variants.
Segment by whether someone has purchased anything.
Segment by purchases from a specific store.
Activity feed item to representing a contact signing up for the list via a ecommerce store.
Segment by amount spent on a single order or across all orders.
A summary of social activity for the campaign, tracked by EepURL.
An individual click location.
A list of a member’s subscriber activity in a specific campaign, including opens, clicks, and bounces.
A list of member’s subscriber activity in a specific campaign.
A summary of the interaction with the campaign.
Activity feed item representing an email to this contact bouncing.
Activity feed item representing having a link clicked by a contact.
Segment by use of a particular email client.
The top email clients based on user-agent strings.
Activity feed item representing an individual reply in a conversation.
Activity feed item representing opening an email.
Segment by email address.
Activity feed item representing having an email sent to the contact.
A summary of an individual Automation workflow email.
A specific event for a contact.
The events that can trigger the webhook and whether they are enabled.
A new event for a specific list member
Exact matches of the provided search query.
All of the following types are flattened into one object:
A facebook ad.
Check if this ad is connected to a facebook page
List settings for the outreach
Report summary of facebook ad
An object describing campaign engagement on Facebook.
A specific feedback message from a specific campaign.
A list of available images and files stored in the File Manager for the account.
A list of all folders in the File Manager.
An individual folder listed in the File Manager.
An individual file listed in the File Manager.
A folder used to organize templates.
An object describing the forwards and forward activity for the campaign.
Partial matches of the provided search query.
An individual file listed in the File Manager.
An individual file listed in the File Manager.
An individual folder listed in the File Manager.
Activity feed item that represents a contact signing up for the audience via a generic some generic method (specifically, one we can’t link to).
Segment by a specific geographic region.
An array of Chimp Chatter messages. There’s a maximum of 200 messages present for an account.
Contains an array of facebook ads.
A collection of landing pages.
An array of objects, each representing an authorized application.
An automation workflow
An array of objects, each representing an Automation workflow.
An array of campaigns.
For sent campaigns, a summary of opens, clicks, and e-commerce data.
The settings for your campaign, including subject, from name, reply-to address, and more.
A collection of Facebook ads.
All of the following types are flattened into one object:
A collection of landing pages.
A collection of ecommerce products.
A single instance of a goal activity.
Segment by Goal activity.
Segment by most recent interaction with a website.
Stats for Group A.
Stats for Group B.
A month-by-month summary of a specific list’s growth activity.
Options for customizing your signup form header.
A summary of a specific list’s growth activity for a specific month and year.
The hours an Automation workflow can send.
Information about a specific product image.
The average campaign statistics for all campaigns in the account’s specified industry.
Assign subscribers to interests to group them together. Interests are referred to as ‘group names’ in the Mailchimp application.
Interest categories organize interests, which are used to group subscribers based on their preferences. These correspond to Group Titles the application.
Information about this list’s interest categories.
A list of this category’s interests
Assign subscribers to interests to group them together. Interests are referred to as ‘group names’ in the Mailchimp application.
Segment by an interest group merge field.
A summary of an individual landing page’s settings and content.
The HTML content for a landing page.
A summary of an individual page’s properties.
A summary of an individual page’s properties.
Activity feed item to representing a contact signing up for the list via a landing page.
A summary of an individual landing page’s settings and content.
Segment by language.
The most recent message in the conversation.
Information about a specific order line.
This object represents a link from the resource where it is found to another resource or action that may be performed.
List settings for the Automation.
Up to the previous 180 days of daily detailed aggregated activity stats for a specific list. Does not include AutoResponder or Automation activity.
The conditions of the segment. Static and fuzzy segments don’t have conditions.
The conditions of the segment. Static and fuzzy segments don’t have conditions.
Contact information displayed in campaign footers to comply with international spam laws.
Information about a specific list segment.
Information about a specific list segment.
A summary of List’s locations.
Individuals who are currently or have been previously subscribed to this list, including members who have bounced or unsubscribed.
Individuals who are currently or have been previously subscribed to this list, including members who have bounced or unsubscribed.
Manage members of a specific Mailchimp list, including currently subscribed, unsubscribed, and bounced members.
Open and click rates for this subscriber.
List Signup Forms.
The average campaign statistics for your list. This won’t be present if we haven’t calculated it yet for this list.
Activity feed item representing this contact unsubscribing from a list.
Webhook configured for the given list.
Manage webhooks for a specific list.
The events that can trigger the webhook and whether they are enabled.
The possible sources of any events that can trigger the webhook and whether they are enabled.
Information about a specific list.
Subscriber location information.
Segment by a specific country or US state.
A single marketing permission a subscriber has either opted-in to or opted-out of.
Activity feed item indicating if a marketing permission was added or updated.
A single marketing permission a subscriber has either opted-in to or opted-out of.
Member activity events.
The last 50 member events for a list.
The member activity events for a given member.
A specific note for a specific member.
Segment by member rating.
Add or remove tags on a member by declaring a tag either active or inactive on a member.
A list of tags assigned to a list member.
Individuals who are currently or have been previously subscribed to this list, including members who have bounced or unsubscribed.
Members to add/remove to/from a static segment
Members found for given search term
Members to subscribe to or unsubscribe from a list.
A merge field (audience field) for a list.
A merge field (audience field) for a list.
A merge field (audience field) for a list.
Extra options for some merge field types.
Extra options for some merge field types.
Individuals who are currently or have been previously subscribed to this list, including members who have bounced or unsubscribed.
Segment by when people subscribed.
Activity feed item representing a note on the contact record.
The most recent Note added about this member.
A list of a member’s opens activity in a specific campaign.
A detailed report of any campaign emails that were opened by a list member.
A summary of the interaction with the campaign.
Top open locations for a specific campaign.
An object describing the open activity for the campaign.
The conditions of the segment. Static segments (tags) and fuzzy segments don’t have conditions.
A collection of an order’s line items.
Information about a specific order.
A collection of orders in an account.
A collection of orders in a store.
The outreach associated with this order. For example, an email campaign or Facebook ad.
Any request query parameters. Example parameters: {“count”:10, “offset”:0}
Segment by poll activity.
Activity feed item representing a time when a contact was sent a particular postcard.
Segment by predicted age.
Segment by predicted gender.
A collection of a store’s products.
Information about an Ecommerce Store’s specific Promo Code
A collection of the store’s promo codes.
Information about an Ecommerce Store’s specific Promo Rule
A collection of the store’s promo rules.
Information about subscribers in an Automation email queue.
List settings for the Automation.
A single instance of a campaign referral.
A summary of the subscribers who were removed from an Automation workflow.
A summary of opens and clicks for sent campaigns.
Report details about a sent campaign.
RSS options, specific to an RSS campaign.
A workflow’s runtime settings for an Automation.
Deprecated
The schedule for sending the RSS Campaign.
The script used to connect your site with Mailchimp.
View members in a specific list segment.
An object representing all segmentation options. This object should contain a
saved_segment_id to use an existing segment, or you can create a new segment by including both match and conditions options.An object representing all segmentation options.
Information about a specific segment.
The send checklist for the campaign.
A list of subscribers who were sent a specific campaign.
A subscriber’s status for a specific campaign.
The settings for the Automation workflow.
The url and password for the VIP report.
The shipping address for the order.
List signup form.
List signup form.
Segment by signup source.
Segment by similar subscribers.
Connected Site
Information about a specific connected site.
The preview for the campaign, rendered by social networks like Facebook and Twitter. Learn more.
Segment by age ranges in Social Profiles data.
Segment by listed gender in Social Profiles data.
Segment by influence rating in Social Profiles data.
Segment by social network in Social Profiles data.
Segment by social network in Social Profiles data.
The possible sources of any events that can trigger the webhook and whether they are enabled.
Activity feed item to representing a contact signing up for the audience from a squatter page.
Segment by a given static segment.
Stats for the list. Many of these are cached for at least five minutes.
An individual tweet.
An individual store in an account.
Collection of Element style for List Signup Forms.
Information about subscribers in an Automation email queue.
Information about subscribers in an Automation email queue.
Information about a specific list.
Default values for campaigns created for this list.
Contact information displayed in campaign footers to comply with international spam laws.
Contact information displayed in campaign footers to comply with international spam laws.
Information about a specific list.
A collection of subscriber lists for this account. Lists contain subscribers who have opted-in to receive correspondence from you or your organization.
Open and click rates for this subscriber.
A summary of a subscriber removed from an Automation workflow.
Segment by interaction with a SurveyMonkey survey.
Represents when a contact completes and submits a survey
A list of tags matching the input query.
Use this template to generate the HTML content of the campaign
Use this template to generate the HTML content for the campaign.
Default content for a template.
A list of template folders
Information about a specific template.
Information about a specific template.
A list an account’s available templates.
Segment by a given text or number merge field.
A collection of this account’s tracked conversations.
The tracking options for the Automation.
The tracking settings applied to this landing page.
Available triggers for Automation workflows.
A summary of Twitter activity for a campaign.
Segment members whose location information is unknown.
A member who unsubscribed from a specific campaign.
A list of members who have unsubscribed from a specific campaign.
Update information about an individual Automation workflow email.
Settings for the campaign including the email subject, from name, and from email address.
A report of links clicked in a specific campaign.
Segment by a specific US ZIP code.
Information about a specific product variant.
The settings specific to A/B test campaigns.
The verified domains currently on the account.
The verified domains currently on the account.
The verified domains currently on the account.
Submit a response to the verification challenge and verify a domain for sending.
Segment by VIP status.
A webhook configured for batch status updates.
Activity feed item to representing a contact signing up for the contact through a website page.
The clicks and visits data from the last five weeks.
Segment by a specific US ZIP code.
Enums
The action that triggers the delay of an Automation email.
All of the following types:
The type of event activity.
Whether the member’s address merge field contains/does not contain a value or is/is not blank.
Whether the member’s address merge field is within a given distance from a city or zip.
The sentiment type for a feedback message.
The type of encoded file. Defaults to zip.
The status of the batch call. Learn more about the batch operation status.
Whether the member’s birthday merge information is/is not a certain date or is/is not blank.
The type of bounce.
The current state of a campaign delivery.
The current status of the campaign.
There are four types of campaigns you can create in Mailchimp. A/B Split campaigns have been deprecated and variate campaigns should be used instead.
The type of segment. Static segments are now known as tags. Learn more about tags.
All of the following types:
The type of event activity.
How the campaign’s content is put together.
Segment by interaction with a campaign via Conversations.
How the campaign’s content is put together. The old drag and drop editor uses ‘template’ while the new editor uses ‘multichannel’. Defaults to template.
Whether the member’s merge information is/is not, is greater/less than a value or is/is not blank.
The type of date field to segment on: The opt-in time for a signup, the date the subscriber was last updated, or the date of their last ecomm purchase.
When the event took place: Before, after, is a specific date, is not a specific date, is blank, or is not blank.
The action that triggers the delay of an automation emails.
Whether the delay settings describe before or after the delay action of an automation email.
The type of delay for an Automation email.
Whether the delay settings describe before or after the delay action of an Automation email.
Whether the member’s merge information is/is not a value or is/is not blank.
Segment by purchases in specific items or categories.
A member who has purchased from a category/specific item that is/is not a specific name, where the category/item name contains/doesn’t contain a specific phrase or string, or a category/item name that starts/ends with a string.
Segment by average spent total, number of orders, total number of products purchased, or average number of products per order.
The type of event activity.
Segment by whether someone has purchased anything.
Segment by purchases from a specific store.
The type of event activity.
Segment by amount spent on a single order or across all orders.
Members who have spent ‘more’ or ‘less’ than then specified value.
The type of event activity.
The type of event activity.
Segment by use of a particular email client.
The operation to determine whether we select clients that match the value, or clients that do not match the value.
Segmenting based off of a subscriber’s email address.
Whether the email address is/not exactly, contains/doesn’t contain, starts/ends with a string.
When to send the Automation email.
The type of event activity.
A unique code that identifies this specifc error.
Type of the audience
Segment by interaction with a specific campaign.
The type of file in the File Manager.
The frequency of the RSS Campaign.
The type of event activity.
Segment members who are within a specific geographic region.
The type of activity
Returns files sorted by the specified field.
Returns files sorted by the specified field.
The status of the campaign.
Returns files sorted by the specified field.
Returns files sorted by the specified field.
Returns notes sorted by the specified field.
Returns files sorted by the specified field.
The subscriber’s status.
Returns files sorted by the specified field.
Returns files sorted by the specified field.
Returns user templates sorted by the specified field.
Segment by Goal activity.
Whether the website URL is/not exactly, contains/doesn’t contain, starts with/ends with a string.
Segment by most recent interaction with a website.
Whether the website activity happened after, before, or at a given timestamp.
The HTTP method to use for the operation.
Image alignment.
Image border style.
Image link target.
Used to filter list members by interests. Must be accompanied by interest_category_id and interest_ids. “any” will match a member with any of the interest supplied, “all” will only match members with every interest supplied, and “none” will match members without any of the interest supplied.
Whether the member is a part of one, all, or none of the groups.
Whether a conversation message has been marked as read.
The type of event activity.
The status of this landing page.
The type of template the landing page has.
Segmenting based off of a subscriber’s language.
Whether the member’s language is or is not set to a specific language.
The type of event activity.
Segmenting subscribers who are within a specific location.
Segment members who are within a specific country or US state.
The type of event activity.
Segment match type.
Segment by member rating.
Members who have have a rating that is/not exactly a given number or members who have a rating greater/less than a given number.
The status for the tag on the member, pass in active to add a tag or inactive to remove it.
Subscriber’s current status.
The type for the merge field.
The HTTP method that should be used when accessing the URL defined in ‘href’.
Segment by when people subscribed.
Whe the event took place, namely within a time frame.
The type of event activity.
The status of the member with regard to their campaign interaction. One of the following: opened, clicked, was sent, didn’t open, didn’t click, or was not sent.
Type of discount. For free shipping set type to fixed
Campaign, Ad, or Page status
Supported Campaign, Ad, Page type
How we should evaluate a winner. Based on ‘opens’, ‘clicks’, or ‘manual’.
Segment by poll activity.
Members have/have not interacted with a specific poll in a Mailchimp email.
The type of event activity.
Segment by predicted age.
Members who are/not the exact criteria listed.
The predicted age to segment.
Segment by predicted gender.
The type of pricing plan the account is on.
The content section name.
Segment by interaction with an Automation workflow.
The status of the member with regard to the automation workflow. One of the following: has started the workflow, has completed the workflow, has not started the workflow, or has not completed the workflow.
A string that identifies the element selector.
The item type.
Choose the type of test email to send.
Whether the member’s signup source was/was not a particular value.
Segment by similar subscribers.
Members who are/are not apart of a ‘similar subscribers’ segment.
Segment by age ranges in Social Profiles data.
Segment by listed gender in Social Profiles data.
The Social Profiles gender to segment.
Segment by influence rating in Social Profiles data.
Members who are/not following a linked account on a given social network.
The social network to segment against.
Segment by social network in Social Profiles data.
The social network to segment against.
Determines the order direction for sorted results.
Returns files sorted by the specified field.
The source of the feedback.
List or Facebook based audience
The type of AB split to run.
The type of event activity.
Segment by a given static segment.
Members who are/are not apart of a static segment.
Restrict the results to automations with the specified status.
Subscriber’s status. This value is required only if the email address is not already present on the list.
Segment by interaction with a SurveyMonkey survey.
The type of event activity.
The target that the discount applies to.
Whether the member’s merge information is/is not, contains/does not contain, starts/ends with, or is greater/less than a value
The Mailchimp tracking code for the order. Uses the ‘mc_tc’ parameter in E-Commerce tracking URLs.
Determines how this category’s interests appear on signup forms.
Segment members for which location information is unknown.
Segment members who are within a specific US zip code.
The age range to segment.
Segment by VIP status.
Legacy - visibility settings are no longer used
How unit of time for measuring the winner (‘hours’ or ‘days’). This cannot be changed after a campaign is sent.
The type of event activity.
The combination that performs the best. This may be determined automatically by click rate, open rate, or total revenue – or you may choose manually based on the reporting data you find the most valuable. For Multivariate Campaigns testing send_time, winner_criteria is ignored. For Multivariate Campaigns with ‘manual’ as the winner_criteria, the winner must be chosen in the Mailchimp web application.
The type of Automation workflow.
Segment members who are/are not within a specific US zip code.