Enum mailchimp_api::types::DateSegmentField
source · pub enum DateSegmentField {
EcommDate,
InfoChanged,
TimestampOpt,
Noop,
FallthroughString,
}Expand description
The type of date field to segment on: The opt-in time for a signup, the date the subscriber was last updated, or the date of their last ecomm purchase.
Variants
EcommDate
InfoChanged
TimestampOpt
Noop
FallthroughString
Implementations