Enum mailchimp_api::types::DateSegmentOperator
source · pub enum DateSegmentOperator {
Blank,
BlankNot,
Greater,
Is,
Less,
Not,
Notwithin,
Within,
Noop,
FallthroughString,
}Expand description
When the event took place: Before, after, is a specific date, is not a specific date, is blank, or is not blank.
Variants
Blank
BlankNot
Greater
Is
Less
Not
Notwithin
Within
Noop
FallthroughString
Implementations