pub enum EmailClientSegmentOperator {
ClientIs,
ClientNot,
Noop,
FallthroughString,
}Expand description
The operation to determine whether we select clients that match the value, or clients that do not match the value.
Variants
ClientIs
ClientNot
Noop
FallthroughString
Implementations