Enum mailchimp_api::types::WaitTime
source · pub enum WaitTime {
Days,
Hours,
Noop,
FallthroughString,
}Expand description
How unit of time for measuring the winner (‘hours’ or ‘days’). This cannot be changed after a campaign is sent.
Variants
Days
Hours
Noop
FallthroughString
Implementations