Struct mailchimp_api::types::Archive
source · pub struct Archive {
pub archive_content: String,
pub archive_type: Option<ArchiveType>,
}Expand description
Available when uploading an archive to create campaign content. The archive should include all campaign content and images. Learn more.
Fields
archive_content: StringThe name of the folder.
archive_type: Option<ArchiveType>Available when uploading an archive to create campaign content. The archive should include all campaign content and images. Learn more.