Struct mailchimp_api::types::AutomationSegment
source · pub struct AutomationSegment {
pub condition_type: Option<AutomationSegmentConditionType>,
pub field: SegmentField,
pub op: SegmentOperator,
pub value: String,
}Expand description
Segment by interaction with an Automation workflow.
Fields
condition_type: Option<AutomationSegmentConditionType>Segment by interaction with an Automation workflow.
field: SegmentFieldSegment by interaction with an Automation workflow.
op: SegmentOperatorThe status of the member with regard to the automation workflow. One of the following: has started the workflow, has completed the workflow, has not started the workflow, or has not completed the workflow.
value: StringThe name of the folder.