pub struct CampaignABTestOptions {
    pub combinations: Vec<Combinations>,
    pub contents: Vec<String>,
    pub from_names: Vec<String>,
    pub reply_to_addresses: Vec<String>,
    pub send_times: Vec<Option<DateTime<Utc>>>,
    pub subject_lines: Vec<String>,
    pub test_size: i64,
    pub wait_time: i64,
    pub winner_criteria: WinnerCriteria,
    pub winning_campaign_id: String,
    pub winning_combination_id: String,
}
The settings specific to A/B test campaigns.

Fields

combinations: Vec<Combinations>

The settings specific to A/B test campaigns.

contents: Vec<String>

The settings specific to A/B test campaigns.

from_names: Vec<String>

The settings specific to A/B test campaigns.

reply_to_addresses: Vec<String>

The settings specific to A/B test campaigns.

send_times: Vec<Option<DateTime<Utc>>>

The settings specific to A/B test campaigns.

subject_lines: Vec<String>

The settings specific to A/B test campaigns.

test_size: i64

The settings specific to A/B test campaigns.

wait_time: i64

The settings specific to A/B test campaigns.

winner_criteria: WinnerCriteria

The combination that performs the best. This may be determined automatically by click rate, open rate, or total revenue – or you may choose manually based on the reporting data you find the most valuable. For Multivariate Campaigns testing send_time, winner_criteria is ignored. For Multivariate Campaigns with ‘manual’ as the winner_criteria, the winner must be chosen in the Mailchimp web application.

winning_campaign_id: String

The settings specific to A/B test campaigns.

winning_combination_id: String

The settings specific to A/B test campaigns.