pub struct CampaignContentVariateContents {
pub archive: Option<Archive>,
pub content_label: String,
pub html: String,
pub plain_text: String,
pub template: Option<TemplateContent>,
pub url: String,
}Fields
archive: Option<Archive>Available when uploading an archive to create campaign content. The archive should include all campaign content and images. Learn more.
content_label: StringThe name of the folder.
html: StringThe name of the folder.
plain_text: StringThe name of the folder.
template: Option<TemplateContent>Use this template to generate the HTML content for the campaign.
url: StringThe name of the folder.