Struct mailchimp_api::types::CampaignReportSummaryData
source · pub struct CampaignReportSummaryData {
pub click_rate: f64,
pub clicks: i64,
pub ecommerce: Option<Ecommerce>,
pub open_rate: f64,
pub opens: i64,
pub subscriber_clicks: i64,
pub unique_opens: i64,
}Expand description
For sent campaigns, a summary of opens and clicks.
Fields
click_rate: f64For sent campaigns, a summary of opens and clicks.
clicks: i64For sent campaigns, a summary of opens and clicks.
ecommerce: Option<Ecommerce>For sent campaigns, a summary of opens and clicks.
open_rate: f64For sent campaigns, a summary of opens and clicks.
opens: i64For sent campaigns, a summary of opens and clicks.
subscriber_clicks: i64For sent campaigns, a summary of opens and clicks.
unique_opens: i64For sent campaigns, a summary of opens and clicks.