Struct mailchimp_api::types::CampaignReports
source · pub struct CampaignReports {
pub links: Vec<Links>,
pub campaign_id: String,
pub feedback: Vec<Feedback>,
pub total_items: i64,
}Expand description
A summary of the comment feedback for a specific campaign.
Fields
links: Vec<Links>A summary of the comment feedback for a specific campaign.
campaign_id: StringA summary of the comment feedback for a specific campaign.
feedback: Vec<Feedback>A summary of the comment feedback for a specific campaign.
total_items: i64A summary of the comment feedback for a specific campaign.