Struct mailchimp_api::types::CreatedCampaign
source · pub struct CreatedCampaign {
pub content_type: Option<CreatedCampaignContentType>,
pub recipients: Option<CreatedCampaignList>,
pub rss_opts: Option<RssOptions>,
pub settings: Option<CreatedCampaignSettings>,
pub social_card: Option<SocialCard>,
pub tracking: Option<CampaignTrackingOptions>,
pub type_: CampaignType,
pub variate_settings: Option<VariateSettings>,
}Expand description
A summary of an individual campaign’s settings and content.
Fields
content_type: Option<CreatedCampaignContentType>A summary of an individual campaign’s settings and content.
recipients: Option<CreatedCampaignList>A summary of an individual campaign’s settings and content.
rss_opts: Option<RssOptions>A summary of an individual campaign’s settings and content.
settings: Option<CreatedCampaignSettings>A summary of an individual campaign’s settings and content.
A summary of an individual campaign’s settings and content.
tracking: Option<CampaignTrackingOptions>A summary of an individual campaign’s settings and content.
type_: CampaignTypeThere are four types of campaigns you can create in Mailchimp. A/B Split campaigns have been deprecated and variate campaigns should be used instead.
variate_settings: Option<VariateSettings>A summary of an individual campaign’s settings and content.