pub struct CreatedCampaignListSegmentOptions {
pub conditions: Vec<ConditionsOneOf>,
pub match_: Option<Match>,
pub saved_segment_id: i64,
}Expand description
An object representing all segmentation options. This object should contain a saved_segment_id to use an existing segment, or you can create a new segment by including both match and conditions options.
Fields
conditions: Vec<ConditionsOneOf>An object representing all segmentation options. This object should contain a saved_segment_id to use an existing segment, or you can create a new segment by including both match and conditions options.
match_: Option<Match>An object representing all segmentation options. This object should contain a saved_segment_id to use an existing segment, or you can create a new segment by including both match and conditions options.
saved_segment_id: i64An object representing all segmentation options. This object should contain a saved_segment_id to use an existing segment, or you can create a new segment by including both match and conditions options.