Struct mailchimp_api::types::CreatedCampaignSettings
source · pub struct CreatedCampaignSettings {Show 15 fields
pub authenticate: bool,
pub auto_fb_post: Vec<String>,
pub auto_footer: bool,
pub auto_tweet: bool,
pub fb_comments: bool,
pub folder_id: String,
pub from_name: String,
pub inline_css: bool,
pub preview_text: String,
pub reply_to: String,
pub subject_line: String,
pub template_id: i64,
pub title: String,
pub to_name: String,
pub use_conversation: bool,
}Expand description
The settings for your campaign, including subject, from name, reply-to address, and more.
Fields
authenticate: boolThe settings for your campaign, including subject, from name, reply-to address, and more.
auto_fb_post: Vec<String>The settings for your campaign, including subject, from name, reply-to address, and more.
The settings for your campaign, including subject, from name, reply-to address, and more.
auto_tweet: boolThe settings for your campaign, including subject, from name, reply-to address, and more.
fb_comments: boolThe settings for your campaign, including subject, from name, reply-to address, and more.
folder_id: StringThe settings for your campaign, including subject, from name, reply-to address, and more.
from_name: StringThe settings for your campaign, including subject, from name, reply-to address, and more.
inline_css: boolThe settings for your campaign, including subject, from name, reply-to address, and more.
preview_text: StringThe settings for your campaign, including subject, from name, reply-to address, and more.
reply_to: StringThe settings for your campaign, including subject, from name, reply-to address, and more.
subject_line: StringThe settings for your campaign, including subject, from name, reply-to address, and more.
template_id: i64The settings for your campaign, including subject, from name, reply-to address, and more.
title: StringThe settings for your campaign, including subject, from name, reply-to address, and more.
to_name: StringThe settings for your campaign, including subject, from name, reply-to address, and more.
use_conversation: boolThe settings for your campaign, including subject, from name, reply-to address, and more.