Struct mailchimp_api::types::DailySend
source · pub struct DailySend {
pub friday: bool,
pub monday: bool,
pub saturday: bool,
pub sunday: bool,
pub thursday: bool,
pub tuesday: bool,
pub wednesday: bool,
}Expand description
The days of the week to send a daily RSS Campaign.
Fields
friday: boolThe days of the week to send a daily RSS Campaign.
monday: boolThe days of the week to send a daily RSS Campaign.
saturday: boolThe days of the week to send a daily RSS Campaign.
sunday: boolThe days of the week to send a daily RSS Campaign.
thursday: boolThe days of the week to send a daily RSS Campaign.
tuesday: boolThe days of the week to send a daily RSS Campaign.
wednesday: boolThe days of the week to send a daily RSS Campaign.