Struct mailchimp_api::types::DateSegment
source · pub struct DateSegment {
pub condition_type: Option<DateSegmentConditionType>,
pub extra: String,
pub field: DateSegmentField,
pub op: DateSegmentOperator,
pub value: String,
}Expand description
Segment by a specific date field.
Fields
condition_type: Option<DateSegmentConditionType>Segment by a specific date field.
extra: StringSegment by a specific date field.
field: DateSegmentFieldThe type of date field to segment on: The opt-in time for a signup, the date the subscriber was last updated, or the date of their last ecomm purchase.
op: DateSegmentOperatorWhen the event took place: Before, after, is a specific date, is not a specific date, is blank, or is not blank.
value: StringThe name of the folder.