Struct mailchimp_api::types::ECommerceCartCustomer
source · pub struct ECommerceCartCustomer {
pub address: Option<Address>,
pub company: String,
pub first_name: String,
pub last_name: String,
pub opt_in_status: bool,
}Expand description
Information about a specific customer. Orders for existing customers should include only the id parameter in the customer object body.
Fields
address: Option<Address>Information about a specific customer. Orders for existing customers should include only the id parameter in the customer object body.
company: StringInformation about a specific customer. Orders for existing customers should include only the id parameter in the customer object body.
first_name: StringInformation about a specific customer. Orders for existing customers should include only the id parameter in the customer object body.
last_name: StringInformation about a specific customer. Orders for existing customers should include only the id parameter in the customer object body.
opt_in_status: boolInformation about a specific customer. Orders for existing customers should include only the id parameter in the customer object body.