Struct mailchimp_api::types::FacebookAdsFeedback
source · pub struct FacebookAdsFeedback {
pub audience: String,
pub budget: String,
pub compliance: String,
pub content: String,
}Expand description
Check if this ad is connected to a facebook page
Fields
audience: StringCheck if this ad is connected to a facebook page
budget: StringCheck if this ad is connected to a facebook page
compliance: StringCheck if this ad is connected to a facebook page
content: StringCheck if this ad is connected to a facebook page