Struct mailchimp_api::types::FileManager
source · pub struct FileManager {
pub links: Vec<Links>,
pub files: Vec<Files>,
pub total_file_size: f64,
pub total_items: i64,
}Expand description
A list of available images and files stored in the File Manager for the account.
Fields
links: Vec<Links>A list of available images and files stored in the File Manager for the account.
files: Vec<Files>A list of available images and files stored in the File Manager for the account.
total_file_size: f64A list of available images and files stored in the File Manager for the account.
total_items: i64A list of available images and files stored in the File Manager for the account.