pub struct GetCampaignsResponseCampaignReportSummary {
pub click_rate: f64,
pub clicks: i64,
pub ecommerce: Option<Ecommerce>,
pub open_rate: f64,
pub opens: i64,
pub subscriber_clicks: i64,
pub unique_opens: i64,
}Expand description
For sent campaigns, a summary of opens, clicks, and e-commerce data.
Fields
click_rate: f64For sent campaigns, a summary of opens, clicks, and e-commerce data.
clicks: i64For sent campaigns, a summary of opens, clicks, and e-commerce data.
ecommerce: Option<Ecommerce>For sent campaigns, a summary of opens, clicks, and e-commerce data.
open_rate: f64For sent campaigns, a summary of opens, clicks, and e-commerce data.
opens: i64For sent campaigns, a summary of opens, clicks, and e-commerce data.
subscriber_clicks: i64For sent campaigns, a summary of opens, clicks, and e-commerce data.
unique_opens: i64For sent campaigns, a summary of opens, clicks, and e-commerce data.