Struct mailchimp_api::types::NewMembers
source · pub struct NewMembers {Show 23 fields
pub links: Vec<Links>,
pub email_address: String,
pub email_client: String,
pub email_type: String,
pub id: String,
pub interests: bool,
pub ip_opt: String,
pub ip_signup: String,
pub language: String,
pub last_changed: Option<DateTime<Utc>>,
pub last_note: Option<Notes>,
pub list_id: String,
pub location: Option<BatchUpdateListMembersNewLocation>,
pub member_rating: i64,
pub merge_fields: Option<Value>,
pub stats: Option<SubscriberStats>,
pub status: Option<StatusIfNew>,
pub tags: Vec<Tags>,
pub tags_count: i64,
pub timestamp_opt: Option<DateTime<Utc>>,
pub timestamp_signup: Option<DateTime<Utc>>,
pub unique_email_id: String,
pub vip: bool,
}Expand description
Individuals who are currently or have been previously subscribed to this list, including members who have bounced or unsubscribed.
Fields
links: Vec<Links>Individuals who are currently or have been previously subscribed to this list, including members who have bounced or unsubscribed.
email_address: StringIndividuals who are currently or have been previously subscribed to this list, including members who have bounced or unsubscribed.
email_client: StringIndividuals who are currently or have been previously subscribed to this list, including members who have bounced or unsubscribed.
email_type: StringIndividuals who are currently or have been previously subscribed to this list, including members who have bounced or unsubscribed.
id: StringIndividuals who are currently or have been previously subscribed to this list, including members who have bounced or unsubscribed.
interests: boolIndividuals who are currently or have been previously subscribed to this list, including members who have bounced or unsubscribed.
ip_opt: StringIndividuals who are currently or have been previously subscribed to this list, including members who have bounced or unsubscribed.
ip_signup: StringIndividuals who are currently or have been previously subscribed to this list, including members who have bounced or unsubscribed.
language: StringIndividuals who are currently or have been previously subscribed to this list, including members who have bounced or unsubscribed.
last_changed: Option<DateTime<Utc>>Individuals who are currently or have been previously subscribed to this list, including members who have bounced or unsubscribed.
last_note: Option<Notes>Individuals who are currently or have been previously subscribed to this list, including members who have bounced or unsubscribed.
list_id: StringIndividuals who are currently or have been previously subscribed to this list, including members who have bounced or unsubscribed.
location: Option<BatchUpdateListMembersNewLocation>Individuals who are currently or have been previously subscribed to this list, including members who have bounced or unsubscribed.
member_rating: i64Individuals who are currently or have been previously subscribed to this list, including members who have bounced or unsubscribed.
merge_fields: Option<Value>Individuals who are currently or have been previously subscribed to this list, including members who have bounced or unsubscribed.
stats: Option<SubscriberStats>Individuals who are currently or have been previously subscribed to this list, including members who have bounced or unsubscribed.
status: Option<StatusIfNew>Individuals who are currently or have been previously subscribed to this list, including members who have bounced or unsubscribed.
Individuals who are currently or have been previously subscribed to this list, including members who have bounced or unsubscribed.
Individuals who are currently or have been previously subscribed to this list, including members who have bounced or unsubscribed.
timestamp_opt: Option<DateTime<Utc>>Individuals who are currently or have been previously subscribed to this list, including members who have bounced or unsubscribed.
timestamp_signup: Option<DateTime<Utc>>Individuals who are currently or have been previously subscribed to this list, including members who have bounced or unsubscribed.
unique_email_id: StringIndividuals who are currently or have been previously subscribed to this list, including members who have bounced or unsubscribed.
vip: boolIndividuals who are currently or have been previously subscribed to this list, including members who have bounced or unsubscribed.