pub struct PostCampaignsActionsScheduleRequest {
pub batch_delivery: Option<BatchDelivery>,
pub schedule_time: Option<DateTime<Utc>>,
pub timewarp: Option<bool>,
}Fields
batch_delivery: Option<BatchDelivery>Choose whether the campaign should use Batch Delivery. Cannot be set to true for campaigns using Timewarp.
schedule_time: Option<DateTime<Utc>>The date and time that the account was created in ISO 8601 format.
timewarp: Option<bool>Whether the webhook is triggered when a list subscriber is added.