Struct mailchimp_api::types::RemovedSubscribers
source · pub struct RemovedSubscribers {
pub links: Vec<Links>,
pub subscribers: Vec<Subscribers>,
pub total_items: i64,
pub workflow_id: String,
}Expand description
A summary of the subscribers who were removed from an Automation workflow.
Fields
links: Vec<Links>A summary of the subscribers who were removed from an Automation workflow.
subscribers: Vec<Subscribers>A summary of the subscribers who were removed from an Automation workflow.
total_items: i64A summary of the subscribers who were removed from an Automation workflow.
workflow_id: StringA summary of the subscribers who were removed from an Automation workflow.