Struct mailchimp_api::types::SentData
source · pub struct SentData {
pub links: Vec<Links>,
pub campaign_id: String,
pub sent_to: Vec<SentTo>,
pub total_items: i64,
}Expand description
A list of subscribers who were sent a specific campaign.
Fields
links: Vec<Links>A list of subscribers who were sent a specific campaign.
campaign_id: StringA list of subscribers who were sent a specific campaign.
sent_to: Vec<SentTo>A list of subscribers who were sent a specific campaign.
total_items: i64A list of subscribers who were sent a specific campaign.