Struct mailchimp_api::types::SubscriberListContactData
source · pub struct SubscriberListContactData {
pub address_1: String,
pub address_2: String,
pub city: String,
pub company: String,
pub country: String,
pub phone: String,
pub state: String,
pub zip: String,
}Expand description
Contact information displayed in campaign footers to comply with international spam laws.
Fields
address_1: StringThe name of the folder.
address_2: StringContact information displayed in campaign footers to comply with international spam laws.
city: StringThe name of the folder.
company: StringThe name of the folder.
country: StringThe name of the folder.
phone: StringContact information displayed in campaign footers to comply with international spam laws.
state: StringThe name of the folder.
zip: StringThe name of the folder.