Struct mailchimp_api::types::VariateSettings
source · pub struct VariateSettings {
pub from_names: Vec<String>,
pub reply_to_addresses: Vec<String>,
pub send_times: Vec<Option<DateTime<Utc>>>,
pub subject_lines: Vec<String>,
pub test_size: i64,
pub wait_time: i64,
pub winner_criteria: WinnerCriteria,
}Expand description
The settings specific to A/B test campaigns.
Fields
from_names: Vec<String>The settings specific to A/B test campaigns.
reply_to_addresses: Vec<String>The settings specific to A/B test campaigns.
send_times: Vec<Option<DateTime<Utc>>>The settings specific to A/B test campaigns.
subject_lines: Vec<String>The settings specific to A/B test campaigns.
test_size: i64The settings specific to A/B test campaigns.
wait_time: i64The settings specific to A/B test campaigns.
winner_criteria: WinnerCriteriaThe combination that performs the best. This may be determined automatically by click rate, open rate, or total revenue – or you may choose manually based on the reporting data you find the most valuable. For Multivariate Campaigns testing send_time, winner_criteria is ignored. For Multivariate Campaigns with ‘manual’ as the winner_criteria, the winner must be chosen in the Mailchimp web application.