Struct mailchimp_api::types::WebsiteSignup
source · pub struct WebsiteSignup {
pub activity_type: Option<WebsiteSignupActivityType>,
pub created_at_timestamp: Option<DateTime<Utc>>,
pub outreach_id: String,
pub outreach_title: String,
}Expand description
Activity feed item to representing a contact signing up for the contact through a website page.
Fields
activity_type: Option<WebsiteSignupActivityType>Activity feed item to representing a contact signing up for the contact through a website page.
created_at_timestamp: Option<DateTime<Utc>>Activity feed item to representing a contact signing up for the contact through a website page.
outreach_id: StringActivity feed item to representing a contact signing up for the contact through a website page.
outreach_title: StringActivity feed item to representing a contact signing up for the contact through a website page.